`define NUM_CORE 10

module oc_aquarius_top(handsome_clk, handsome_din_top, handsome_dout_top, CLK_SRC, RST_n);
	input handsome_clk;
	input handsome_din_top;
	output handsome_dout_top;
	input CLK_SRC;
	input RST_n;

localparam input_width = 15;
localparam output_width = 18;
localparam reducer_log4 = 3;
localparam reducer_log4_top = 2;

wire [`NUM_CORE-1:0] RXD;
wire [`NUM_CORE-1:0] CTS;
wire [`NUM_CORE-1:0] LCDRS;
wire [`NUM_CORE-1:0] LCDRW;
wire [`NUM_CORE-1:0] LCDE;
wire [`NUM_CORE-1:0] TXD;
wire [`NUM_CORE-1:0] RTS;
wire [7:0] LCDDBI [`NUM_CORE-1:0];
wire [4:0] KEYXI [`NUM_CORE-1:0];
wire [7:0] LCDDBO [`NUM_CORE-1:0];
wire [4:0] KEYYO [`NUM_CORE-1:0];
wire [`NUM_CORE-1:0] handsome_din;
wire [`NUM_CORE-1:0] handsome_dout;

handsome_lfsr #(`NUM_CORE) input_lfsr_top (
			.clock(handsome_clk),
			.input_bit(handsome_din_top),
			.output_vector(handsome_din));

generate
begin:G1
	genvar i;
	for (i = 0; i < `NUM_CORE; i = i+1)
	begin :stamp_inst

		handsome_lfsr #(input_width) input_lfsr (
			.clock(handsome_clk),
			.input_bit(handsome_din[i]),
			.output_vector({RXD[i],CTS[i],LCDDBI[i],KEYXI[i]}));

		oc_aquarius oc_stamp(
			.CLK_SRC(CLK_SRC),
			.RST_n(RST_n),
			.RXD(RXD[i]),
			.CTS(CTS[i]),
			.LCDDBI(LCDDBI[i]),
			.KEYXI(KEYXI[i]),
			.LCDRS(LCDRS[i]),
			.LCDRW(LCDRW[i]),
			.LCDE(LCDE[i]),
			.TXD(TXD[i]),
			.RTS(RTS[i]),
			.LCDDBO(LCDDBO[i]),
			.KEYYO(KEYYO[i]));

		handsome_reducer #(reducer_log4) output_reducer (
			.clock(handsome_clk),
			.input_vector({LCDRS[i],LCDRW[i],LCDE[i],TXD[i],RTS[i],LCDDBO[i],KEYYO[i]}),
			.output_bit(handsome_dout[i]));

	end

handsome_reducer #(reducer_log4_top) output_reducer_top (
	.clock(handsome_clk),
	.input_vector(handsome_dout[`NUM_CORE-1:0]),
	.output_bit(handsome_dout_top));

end
endgenerate
endmodule
